==> radiance-ui-2.0.7.tgz: package/lib/shared-components/button/components/roundButton/index.js <==
import { jsx as ___EmotionJSX } from "@emotion/core";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import Loader from '../../shared-components/loader';
import { RoundButtonWrapper, RoundButtonBase, roundButtonLoader, RoundButtonText, RoundButtonContainer } from './style';
var propTypes = {
  onClick: PropTypes.func,
  disabled: PropTypes.bool,
  children: PropTypes.node,
  buttonType: PropTypes.oneOf(['primary', 'secondary', 'tertiary', 'quaternary']),
  loading: PropTypes.bool,
  icon: PropTypes.node.isRequired,
  textColor: PropTypes.string
};
var defaultProps = {
  disabled: false,
  buttonType: 'primary',
  loading: false,
  onClick: function onClick() {},
  children: '',
  textColor: ''
};

var RoundButton = function RoundButton(_ref) {
  var onClick = _ref.onClick,
      disabled = _ref.disabled,
      children = _ref.children,
      buttonType = _ref.buttonType,
      loading = _ref.loading,
      icon = _ref.icon,
      textColor = _ref.textColor,
      rest = _objectWithoutProperties(_ref, ["onClick", "disabled", "children", "buttonType", "loading", "icon", "textColor"]);

  return ___EmotionJSX(RoundButtonWrapper, {
    onClick: !disabled && !loading ? onClick : function () {
      return false;
    },
    disabled: disabled,
    loading: loading
  }, ___EmotionJSX(RoundButtonBase, _extends({
    disabled: disabled,
    buttonType: buttonType,
    loading: loading,
    type: "button",
    textColor: textColor
  }, rest), icon, ___EmotionJSX(Loader, {
    loading: loading,
    disabled: disabled,
    buttonType: buttonType,
    css: roundButtonLoader(disabled),
    textColor: textColor
  })), children && ___EmotionJSX(RoundButtonText, null, children));
};

RoundButton.propTypes = propTypes;
RoundButton.defaultProps = defaultProps;
RoundButton.Container = RoundButtonContainer;
export default RoundButton;

==> radiance-ui-2.0.19.tgz: package/lib/shared-components/button/components/roundButton/index.js <==
import { jsx as ___EmotionJSX } from "@emotion/core";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import Loader from '../../shared-components/loader';
import { RoundButtonWrapper, RoundButtonBase, roundButtonLoader, RoundButtonText, RoundButtonContainer } from './style';
var propTypes = {
  onClick: PropTypes.func,
  disabled: PropTypes.bool,
  children: PropTypes.node,
  buttonType: PropTypes.oneOf(['primary', 'secondary', 'tertiary', 'quaternary']),
  loading: PropTypes.bool,
  icon: PropTypes.node.isRequired,
  textColor: PropTypes.string
};
var defaultProps = {
  disabled: false,
  buttonType: 'primary',
  loading: false,
  onClick: function onClick() {},
  children: '',
  textColor: ''
};

var RoundButton = function RoundButton(_ref) {
  var onClick = _ref.onClick,
      disabled = _ref.disabled,
      children = _ref.children,
      buttonType = _ref.buttonType,
      loading = _ref.loading,
      icon = _ref.icon,
      textColor = _ref.textColor,
      rest = _objectWithoutProperties(_ref, ["onClick", "disabled", "children", "buttonType", "loading", "icon", "textColor"]);

  return ___EmotionJSX(RoundButtonWrapper, null, ___EmotionJSX(RoundButtonBase, _extends({
    onClick: !disabled && !loading ? onClick : function () {
      return false;
    },
    disabled: disabled,
    buttonType: buttonType,
    loading: loading,
    type: "button",
    textColor: textColor
  }, rest), icon, ___EmotionJSX(Loader, {
    loading: loading,
    disabled: disabled,
    buttonType: buttonType,
    css: roundButtonLoader(disabled),
    textColor: textColor
  })), children && ___EmotionJSX(RoundButtonText, null, children));
};

RoundButton.propTypes = propTypes;
RoundButton.defaultProps = defaultProps;
RoundButton.Container = RoundButtonContainer;
export default RoundButton;
